==> 0.1.4-alpha.tar.gz: bin/pub.dart <==
// read pubspec.yaml, open links in browser

import 'dart:core';
import 'dart:io';
import 'dart:isolate';

import 'package:args/args.dart';
import 'package:logging/logging.dart';
// import 'package:package_config/package_config.dart';
import 'package:path/path.dart' as path;
import 'package:pubspec_yaml/pubspec_yaml.dart';
import 'package:sprintf/sprintf.dart';

import 'package:dartrix/dartrix.dart';

import 'package:dartrix/src/config.dart';
// import 'package:dartrix/src/data.dart';
import 'package:dartrix/src/debug.dart' as debug;
import 'package:dartrix/src/utils.dart';

var _log = Logger('pub');

void printUsage(ArgParser argParser) async {
  print('dartrix:pub, version 0.1.0\n');
  print('Usage: pub global run dartrix:pub [hv] [library]\n');
  // print('Options (for builtins and plugin libraries only):\n');
  print(argParser.usage);

}

void main(List<String> args) async {
  Logger.root.level = Level.ALL;
  Logger.root
    ..onRecord.listen((record) {
      var level;
      switch (record.level.name) {
        case 'SHOUT':
          level = shoutPen(record.level.name);
          break;
        case 'SEVERE':
          level = severePen(record.level.name);
          break;
        case 'WARNING':
          level = warningPen(record.level.name);
          break;
        case 'INFO':
          level = infoPen(record.level.name);
          break;
        case 'CONFIG':
          level = configPen(record.level.name);
          break;
        default:
          level = record.level.name;
          break;
      }
      print('${record.loggerName} ${level}: ${record.message}');
    });

  var argParser = ArgParser(usageLineLength: 120);
  // argParser.addOption('template', abbr: 't',
  //   valueHelp: '[a-z_][a-z0-9_]*',
  //   help: 'Template name.',
  //   // defaultsTo: 'plugin',
  //   // callback: (t) => validateTemplateName(t)
  // );
  argParser.addFlag('help', abbr: 'h', defaultsTo: false);
  argParser.addFlag('verbose', abbr: 'v', defaultsTo: false);
  argParser.addFlag('debug', defaultsTo: false);

  Config.options = argParser.parse(args);

  Config.verbose = Config.options['verbose'];
  debug.debug = Config.options['debug'];

  if (debug.debug) debug.debugOptions();

  // var root = path.dirname(Platform.script.toString());
  // print('proj root: $root');

  if (Config.options['help']) {
    await printUsage(argParser);
    exit(0);
  }

  if (Config.options.rest.isEmpty) {
    //listBuiltins(Config.options);
    printUsage(argParser);
  } else {
    switch (Config.options.rest[0]) {
      case 'help':
      case '-h':
      case '--help':
        await printUsage(argParser);
        exit(0);
        break;
      default:
    }
  }
}

==> 0.1.5-alpha.tar.gz: bin/pub.dart <==
// read pubspec.yaml, open links in browser

import 'dart:core';
import 'dart:io';
// import 'dart:isolate';

import 'package:args/args.dart';
// import 'package:logging/logging.dart';
// import 'package:package_config/package_config.dart';
// import 'package:path/path.dart' as path;
// import 'package:pubspec_yaml/pubspec_yaml.dart';
// import 'package:sprintf/sprintf.dart';

import 'package:dartrix/dartrix.dart';

import 'package:dartrix/src/config.dart';
// import 'package:dartrix/src/data.dart';
import 'package:dartrix/src/debug.dart' as debug;
// import 'package:dartrix/src/utils.dart';

// var _log = Logger('pub');

void printUsage(ArgParser argParser) async {
  print('dartrix:pub, version 0.1.0\n');
  print('Usage: pub global run dartrix:pub [hv] [library]\n');
  // print('Options (for builtins and plugin libraries only):\n');
  print(argParser.usage);
}

void main(List<String> args) async {
  // Logger.root.level = Level.ALL;
  // Logger.root
  //   ..onRecord.listen((record) {
  //     var level;
  //     switch (record.level.name) {
  //       case 'SHOUT':
  //         level = shoutPen(record.level.name);
  //         break;
  //       case 'SEVERE':
  //         level = severePen(record.level.name);
  //         break;
  //       case 'WARNING':
  //         level = warningPen(record.level.name);
  //         break;
  //       case 'INFO':
  //         level = infoPen(record.level.name);
  //         break;
  //       case 'CONFIG':
  //         level = configPen(record.level.name);
  //         break;
  //       default:
  //         level = record.level.name;
  //         break;
  //     }
  //     print('${record.loggerName} ${level}: ${record.message}');
  //   });

  var argParser = ArgParser(usageLineLength: 120);
  // argParser.addOption('template', abbr: 't',
  //   valueHelp: '[a-z_][a-z0-9_]*',
  //   help: 'Template name.',
  //   // defaultsTo: 'plugin',
  //   // callback: (t) => validateTemplateName(t)
  // );
  argParser.addFlag('help', abbr: 'h', defaultsTo: false);
  argParser.addFlag('verbose', abbr: 'v', defaultsTo: false);
  argParser.addFlag('debug', defaultsTo: false);

  Config.options = argParser.parse(args);

  Config.verbose = Config.options['verbose'];
  debug.debug = Config.options['debug'];

  if (debug.debug) debug.debugOptions();

  // var root = path.dirname(Platform.script.toString());
  // print('proj root: $root');

  if (Config.options['help']) {
    await printUsage(argParser);
    exit(0);
  }

  if (Config.options.rest.isEmpty) {
    //listBuiltins(Config.options);
    printUsage(argParser);
  } else {
    switch (Config.options.rest[0]) {
      case 'help':
      case '-h':
      case '--help':
        await printUsage(argParser);
        exit(0);
        break;
      default:
    }
  }
}
